container - GooeyPy Docs

Documentation
Overview
gui

- app
- widget
- styleset
- effects

widgets

- label
- button
- input
- slider
- container
- box
- selectbox
- textblock
- image

- Container
- Container.add
- Container.remove

# Container

Container([scrollable]) -> Container widget

A base container widget for containing other widgets. (gosh that's descriptive!) scrollable is for wether or not the container is, well, scrollable (this feature isn't complete yet, but still usable)!

## Container.add

Container.add(widgets) -> None

Add widgets to Container.

### Arguments

widgets
  can ether be a single widget or a list of widgets.

## Container.remove

Container.remove(widgets) -> None

Remove widgets from Container.

### Arguments

widgets
  can ether be a single widget or a list of widgets.